import QtQuick 1.1
import com.nokia.meego 1.1
import QtMobility.location 1.2

import "Storage.js" as Storage

Page {
    tools: detailedLogsTools
    orientationLock: PageOrientation.LockPortrait

    property int lognumberV: 0
    property int logruntimeV: 0
    property real thistripMaxSpeed: 0
    property int thistripS: 0
    property int thistripD: 0
    property int modelS: 0
    property int hourV: 0
    property int minV: 0
    property int secV: 0
    property string hourTV: ""
    property string minTV: ""
    property string secTV: ""
    Coordinate{ id: newLocationT; }

    //Make new track
    function newTrack() {
        //livetrackmodel.clear()
        var temptracksmodel = null;
        var tracklen = trackpolyline.path.length
        if (tracklen > 0) {
            for (var index = 0; index < tracklen -1; index++) {
                trackpolyline.removeCoordinate(trackpolyline.path[0])
            }
        }
        temptracksmodel = Storage.trackingCoOrd(lognumberV);
        for (var i = 0; i < temptracksmodel.length; i ++) {
            newLocationT.latitude = temptracksmodel[i].lvtklat
            newLocationT.longitude = temptracksmodel[i].lvtklon
            trackpolyline.addCoordinate(newLocationT)
        }
    }

    Component.onCompleted: {
    }

    ListModel {
        id: detailedlogsmodel
    }

    //Delegate for This Log
    Component {
        id: oldlogsDelegate
        Rectangle  {
            height: 45
            width: parent.width
            color: "transparent"
            Row {
                clip: true
                spacing: 10
                anchors.verticalCenter: parent.verticalCenter
                Label {
                    text: logstarttime
                    font.bold: true
                    width: 115
                }
                Label {
                    width: 145
                    text: logruntime>= 60 ? Math.floor(logruntime/60) + " Minutes" : logruntime + " Seconds"
                }
                Label {
                    color: "grey"
                    text: logtotaldistance >= 1000 ?  Math.floor(logtotaldistance/1000) + " KMs" : Math.floor(logtotaldistance) + " Metres"
                }
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("LogViewDetailsPage.qml"), {lognumberV: lognumber, logruntimeV: logruntime})
                }
            }
        }
    }
    //Section Delegate
    Component {
        id: sectionHeader
        Rectangle {
            id: sectionHeading
            height: 40
            width: parent.width
            color: "transparent" //"#111111"
            Label {
                id: headingText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                text: "Logs collected on " + section
                height: paintedHeight + platformStyle.paddingLarge
                verticalAlignment: Text.AlignVCenter
                color: "lightgrey"
                font.capitalization: Font.SmallCaps
            }
            Rectangle {
                width: parent.width
                height: 1
                color: "lightgrey"
                anchors.bottom: parent.bottom
            }
        }
    }

    onStatusChanged: {
        if (status == PageStatus.Activating ) {
            var tempdetailedlogsmodel = []
            detailedlogsmodel.clear()
            tempdetailedlogsmodel = Storage.detailedogstoview(lognumberV);
            for (var i = 0; i < tempdetailedlogsmodel.length; i ++) {
                detailedlogsmodel.append(tempdetailedlogsmodel[i])
            }
            modelS = detailedlogsmodel.count - 1
            thistripD = Storage.detailedogstoviewD(lognumberV)
            thistripMaxSpeed = Storage.detailedogstoviewSpeed(lognumberV)
            thistripS = Storage.detailedogstoviewS(lognumberV)
            if (logruntimeV >= 3600) {
                hourV = Math.floor(logruntimeV/3600)
                if(hourV==1){hourTV = " Hour "} else {hourTV = " Hours "}
                minV = Math.floor((logruntimeV-hourV*3600)/60)
                if(minV==1){minTV = " minute "} else {minTV = " minutes "}
                secV = (logruntimeV-(hourV*3600+minV*60))
                if(secV==1){secTV = " second."} else {secTV = " seconds."}
                logruntimetext.text =  hourV + hourTV + minV + minTV + secV + secTV
            }
            if (logruntimeV >= 60 && logruntimeV < 3600) {
                hourV = 0
                hourTV = ""
                minV = Math.floor(logruntimeV/60)
                if(minV==1){minTV = " Minute "} else {minTV = " Minutes "}
                secV = logruntimeV-minV*60
                if(secV==1){secTV = " second."} else {secTV = " seconds."}
                logruntimetext.text =  minV + minTV + secV + secTV
            }
            if (logruntimeV < 60 && logruntimeV > 0) {
                hourV = 0
                hourTV = ""
                minV = 0
                minTV = ""
                secV = logruntimeV
                if(secV==1){secTV = " Second."} else {secTV = " Seconds."}
                logruntimetext.text =  secV + secTV
            }
            thistripMaxSpeed = (thistripMaxSpeed * 3.6).toFixed(2)
            logspeedtext.text = thistripMaxSpeed + " Km/h"
            mapOldLogPage.center.latitude = detailedlogsmodel.get(modelS).lat
            mapOldLogPage.center.longitude = detailedlogsmodel.get(modelS).lon
            newTrack()
            indicatorUpload.running = false
            indicatorUpload.visible = false
        }
        if (status == PageStatus.Deactivating) {
            indicatorDelete.running = false
            indicatorDelete.visible = false
            indicatorUpload.running = false
            indicatorUpload.visible = false
        }
    }

    Column {
        anchors.top: parent.top
        anchors.topMargin: 20
        width: parent.width
        height: childrenRect.height
        spacing: 15

        Row {
            spacing: 20
            width: parent.width - 20
            anchors.horizontalCenter: parent.horizontalCenter
            height: childrenRect.height
            Image {
                source: "GPSLogMee80.png"
                //opacity: 0.3
            }
            Column {
                spacing: 5
                width: 300
                Label {
                    text: "GPS LogMee"
                    font.pixelSize: 30
                    //opacity: 0.3
                }
                Label {
                    text: "GPS Logger for N9/N950"
                    font.pixelSize: 18
                    //opacity: 0.3
                }
            }

        }

        Label {
            width: parent.width - 40
            text: "There were a total of " + (parseInt(thistripS) + 1) + " samples."
            wrapMode: Text.WordWrap
            maximumLineCount: 3
            font.pixelSize: 22
            font.capitalization: Font.SmallCaps
            anchors.horizontalCenter: parent.horizontalCenter
        }

        Row {
            width: parent.width - 40
            spacing: 10
            anchors.horizontalCenter: parent.horizontalCenter
            Label {
                width: 120
                text: "Log Time:"
                font.pixelSize: 22
                anchors.top: parent.top
                anchors.topMargin: 10

            }
            Label {
                id: logruntimetext
                width: 300
                wrapMode: Text.WordWrap
                maximumLineCount: 2
                font.pixelSize: 40
            }
        }
        Row {
            width: parent.width - 40
            spacing: 10
            anchors.horizontalCenter: parent.horizontalCenter
            Label {
                width: 120
                text: "Distance:"
                font.pixelSize: 22
                anchors.top: parent.top
                anchors.topMargin: 10

            }
            Label {
                id: logdistancetext
                width: 300
                wrapMode: Text.WordWrap
                maximumLineCount: 2
                font.pixelSize: 40
                text: thistripD < 1000 ? thistripD + " Metres." : (thistripD/1000).toFixed(2) + " KMs."
            }
        }
        Row {
            width: parent.width - 40
            spacing: 10
            anchors.horizontalCenter: parent.horizontalCenter
            Label {
                width: 120
                text: "Max Speed:"
                font.pixelSize: 22
                anchors.top: parent.top
                anchors.topMargin: 10

            }
            Label {
                id: logspeedtext
                width: 300
                wrapMode: Text.WordWrap
                maximumLineCount: 2
                font.pixelSize: 40
            }
        }
        Rectangle {
            color: "#333333"
            radius: 5
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width - 20
            height: 320

            Map {
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.top: parent.top
                anchors.topMargin: 10
                id: mapOldLogPage
                plugin : Plugin {
                    name : "nokia";
                }
                height: 300
                width: parent.width - 20
                size.width: parent.width - 20
                size.height: 300
                zoomLevel: 16
                center: Coordinate {
                              latitude: 0 //endpointLat
                              longitude: 0 //0 //endpointLon
                          }
                mapType: Map.StreetMap
                MapPolyline {
                    id: trackpolyline
                    border {color: "red"; width: 5}
                }
            }
            PinchArea {
                id: pincharea
                //! Holds previous zoom level value
                property double __oldZoom
                anchors.fill: parent
                //! Calculate zoom level
                function calcZoomDelta(zoom, percent) {
                    return zoom + Math.log(percent)/Math.log(2)
                }
                //! Save previous zoom level when pinch gesture started
                onPinchStarted: {
                    __oldZoom = mapOldLogPage.zoomLevel
                }
                //! Update map's zoom level when pinch is updating
                onPinchUpdated: {
                    mapOldLogPage.zoomLevel = calcZoomDelta(__oldZoom, pinch.scale)
                }
                //! Update map's zoom level when pinch is finished
                onPinchFinished: {
                    mapOldLogPage.zoomLevel = calcZoomDelta(__oldZoom, pinch.scale)
                }
            }
            MouseArea {
                id: mousearea

                //! Property used to indicate if panning the map
                property bool __isPanning: false

                //! Last pressed X and Y position
                property int __lastX: -1
                property int __lastY: -1

                anchors.fill : parent

                //! When pressed, indicate that panning has been started and update saved X and Y values
                onPressed: {
                    //flickableLogging.interactive = false
                    __isPanning = true
                    __lastX = mouse.x
                    __lastY = mouse.y
                }

                //! When released, indicate that panning has finished
                onReleased: {
                    __isPanning = false
                }

                //! Move the map when panning
                onPositionChanged: {
                    if (__isPanning) {
                        var dx = mouse.x - __lastX
                        var dy = mouse.y - __lastY
                        mapOldLogPage.pan(-dx, -dy)
                        __lastX = mouse.x
                        __lastY = mouse.y
                    }
                }

                //! When canceled, indicate that panning has finished
                onCanceled: {
                    __isPanning = false;
                }

                //! Zoom one level when double clicked
                onDoubleClicked: {
                    mapOldLogPage.center = mapLoggingPage.toCoordinate(Qt.point(__lastX,__lastY))
                    mapOldLogPage.zoomLevel += 1
                }

            }
        }


    }

    BusyIndicator {
        id: indicatorDelete
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running:  false
        visible: false
    }


    ToolBarLayout {
        id: detailedLogsTools
        ToolIcon {
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked: pageStack.pop()
        }
        ToolIcon {
            platformIconId: "toolbar-list"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: mapLog.open()
        }
    }

    QueryDialog {
        id: queryLogDialog
        acceptButtonText: "Delete"
        rejectButtonText: "Cancel"
        titleText: "Delete Log?"
        message: "Do you want to delete this log?\n"
        onAccepted: {
            indicatorDelete.running = true
            indicatorDelete.visible = true
            Storage.deletethislog(lognumberV)
            pageStack.pop()
        }
        onRejected: { queryLogDialog.close() }
     }

    BusyIndicator {
        id: indicatorUpload
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 300
        platformStyle: BusyIndicatorStyle { size: "large" }
        running:  false
        visible: false
    }


    Menu {
        id: mapLog
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: "Full Screen Map"
                onClicked: {
                    indicatorDelete.running = true
                    indicatorDelete.visible = true
                    appWindow.pageStack.push(Qt.resolvedUrl("OldMapPage.qml"), {lognumberV: lognumberV})
                }
            }
            MenuItem {
                text: "Save Track on Phone"
                onClicked: {
                    mapLog.close()
                    //indicatorUpload.running = true
                    //indicatorUpload.visible = true
                    appWindow.pageStack.push(Qt.resolvedUrl("LogSaver.qml"), {logNumberU: lognumberV})
                }
            }
            MenuItem {
                text: "Upload Track Online"
                onClicked: {
                    mapLog.close()
                    indicatorUpload.running = true
                    indicatorUpload.visible = true
                    //uploadbutton.enabled = false
                    appWindow.pageStack.push(Qt.resolvedUrl("LogUploader.qml"), {logNumberO: lognumberV})
                }

            }
            MenuItem {
                text: "Delete Track"
                onClicked: queryLogDialog.open()
            }
        }
    }


}
