import QtQuick 1.1
import com.nokia.meego 1.1
import QtMobility.location 1.2

import "Storage.js" as Storage

Page {
    tools: startTools
    orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
    }

    onStatusChanged: {
        if (status == PageStatus.Activating ) {
            logPosition.active = true
            if (bounceback === false){
                loggingtimer.running = true
                newLogEntry()
                logruntime = 0
                firstlogrun = true
                pauseTarget = Math.floor(300/updatetimer)
                //console.log("Target to hit => ",pauseTarget)
            }
        }
        if (status == PageStatus.Active) {
            loggingWorker()
        }
    }

    property string startdate: ""
    property string starttime: ""
    property bool firstlogrun: false
    property string runTimeText: ""
    property string runDistaceText: ""
    property int hourV: 0
    property int minV: 0
    property int secV: 0
    property string hourTV: ""
    property string minTV: ""
    property string secTV: ""
    property real topspeed: 0

    property int pauseStreak: 0
    property int pauseCounter: 0
    property int pauseTarget: 0


    //property Coordinate mass: centerLocation
    Coordinate{ id: centerLocation; }
    Coordinate{ id: newLocation; }

    PositionSource {
         id: logPosition
         updateInterval: updatetimer * 500
         active: false
     }

    //Timer to update the details on screen
    Timer {
        id: loggingtimer
        running: false
        repeat: true
        interval: updatetimer*1000 //3000
        onTriggered: {
            loggingWorker()
        }
    }

    //Timer to track the total run time of this log
    Timer {
        id: runtimer
        running: false
        repeat: true
        interval: 1000
        onTriggered: {
            logruntime++
            runTime()
            runDistance()
        }
    }

    Rectangle {
        id: gpsActiveBox
        z: 50
        radius: 10
        height: 100
        width: parent.width - 50
        anchors.top: parent.top
        anchors.topMargin: 115
        anchors.horizontalCenter: parent.horizontalCenter
        color: "green"
        visible: false
        Label {
            font.pixelSize: 40
            color: "white"
            anchors.centerIn: parent
            text: "GPS Active"
        }
    }

    //Function to format run time into nice text to display
    function runTime() {
        if (platformWindow.viewMode == 1) {
            gpsActiveBox.visible = true
        }
        if (platformWindow.viewMode == 0) {
            gpsActiveBox.visible = false
            if (logruntime >= 3600) {
                hourV = Math.floor(logruntime/3600)
                if(hourV<10){hourTV = "0"} else {hourTV = ""}
                minV = Math.floor((logruntime-hourV*3600)/60)
                if(minV<10){minTV = "0"} else {minTV = ""}
                secV = (logruntime-(hourV*3600+minV*60))
                if(secV<10){secTV = "0"} else {secTV = ""}
                runTimeText = hourTV + hourV + ":" + minTV+minV + ":" + secTV + secV
            }
            if (logruntime >= 60 && logruntime < 3600) {
                hourV = 0
                hourTV = ""
                minV = Math.floor(logruntime/60)
                if(minV<10){minTV = "0"} else {minTV = ""}
                secV = logruntime-minV*60
                if(secV<10){secTV = "0"} else {secTV = ""}
                runTimeText =  "00:" + minTV + minV + ":" + secTV + secV
            }
            if (logruntime < 60 && logruntime > 0) {
                hourV = 0
                hourTV = ""
                minV = 0
                minTV = ""
                secV = logruntime
                if(secV<10){secTV = "0"} else {secTV = ""}
                runTimeText =  "00:00:" + secTV + secV
            }

        }
    }

    // Check if there has been no movement for 5 minutes and then pause
    function pauseChecker() {
        pauseCounter++
        //console.log("Pause Checker hit => ",pauseCounter)
        if(pauseCounter >= pauseTarget) {
            //console.log("Stop it all, PAUSE!")
            loggingtimer.running = false
            runtimer.running = false
            Storage.stoplog(logruntime)
            firstlogrun = false
            nowLogging = false
            bounceback = false
            pageStack.pop()
        }
    }

    //Function to format run time into nice text to display
    function runDistance() {
        if (platformWindow.viewMode == 0) {
            if (5000 >= 1000) {
                runDistaceText =  (totald/1000).toFixed(2) + " Km"
            }
            if (totald < 1000) {
                runDistaceText =  totald.toFixed(0) + " Metres"
            }
        }
    }

    //Make new entry into LogIndex Table when starting
    // Add one to the current count variable of Log Index
    function newLogEntry() {
        startdate = (Qt.formatDate(new Date(), "dd-MM-yy")).toString()
        starttime = (Qt.formatTime(new Date(), "hh:mm:ss")).toString()
        Storage.newlog(startdate,starttime)
        nowLogging = true
        countlogindexes++;
    }

    // Check if there has been no movement for 5 minutes and then pause
    function checkPause() {
        if(logPosition.position.speedValid === true && logPosition.position.speed == 0) {
            pauseCounter++
            console.log("Pause Count: ",pauseCounter)
        }
        if(logPosition.position.speedValid === true && logPosition.position.speed > 0) {
            pauseCounter = 0
            console.log("Pause Count: ",pauseCounter)
        }
    }

    //Uses the details from PositionSource to provide updates
    function loggingWorker() {
        //console.log("windowState.visible",windowState.visible,"windowState.active",windowState.active,"windowState.viewModeString",windowState.viewModeString)
        if (logPosition.position.longitudeValid == true && logPosition.position.latitudeValid == true) {
            if(firstlogrun === true) {
                centerLocation.latitude = logPosition.position.coordinate.latitude
                centerLocation.longitude = logPosition.position.coordinate.longitude
                firstlogrun = false
                d = 0;
                runtimer.running = true
                logPosition.updateInterval = freqtimeFAV * 500 // Provide updates at half the time of the update to SQL, Ensures recent update available before commit to SQL
                Storage.newentry(currentlogindex,logPosition.position.coordinate.latitude,logPosition.position.coordinate.longitude,logPosition.position.speed,0,logPosition.position.coordinate.altitude,logPosition.position.timestamp)
            }
            else {
                d = logPosition.position.coordinate.distanceTo(centerLocation)
                //console.log("Distance To in this step =>",d)
                if( d <= 1 & pauseOK == true) {
                    pauseStreak = 1
                    pauseChecker()
                }
                else {
                    pauseStreak = 0
                    pauseCounter = 0
                }
                Storage.newentry(currentlogindex,logPosition.position.coordinate.latitude,logPosition.position.coordinate.longitude,logPosition.position.speed,d,logPosition.position.coordinate.altitude,logPosition.position.timestamp)
                centerLocation.latitude = logPosition.position.coordinate.latitude
                centerLocation.longitude = logPosition.position.coordinate.longitude
            }
            //console.log("New Entry with the Details: ",currentlogindex,logPosition.position.coordinate.latitude,logPosition.position.coordinate.longitude,logPosition.position.speed,d)
        }
    }

    Column {
        anchors.top: parent.top
        anchors.topMargin: 20
        width: parent.width
        height: childrenRect.height
        spacing: 15

        Row {
            spacing: 20
            width: parent.width - 20
            anchors.horizontalCenter: parent.horizontalCenter
            height: childrenRect.height
            Image {
                source: "GPSLogMee80.png"
                //opacity: 0.3
            }
            Column {
                spacing: 5
                width: 300
                Label {
                    text: "GPS LogMee"
                    font.pixelSize: 30
                    //opacity: 0.3
                }
                Label {
                    text: "GPS Logger for N9/N950"
                    font.pixelSize: 18
                    //opacity: 0.3
                }
            }

        }

        Label {
            height: paintedHeight
            text: "Logging will start as soon as a valid sample is available. Samples are only based on Latitude and Longitude details."
            wrapMode: Text.WordWrap
            maximumLineCount: 3
            width: parent.width - 20
            anchors.horizontalCenter: parent.horizontalCenter
            font.pixelSize: 22
            font.capitalization: Font.SmallCaps
        }

        Column {
            spacing: 5
            width: parent.width - 20
            height: childrenRect.height + 10
            Label {
                text: "Run Time:"
                wrapMode: Text.WordWrap
                maximumLineCount: 1
                width: parent.width - 20
                anchors.horizontalCenter: parent.horizontalCenter
                verticalAlignment: Text.AlignBottom
                font.pixelSize: 18
                font.capitalization: Font.SmallCaps
            }
            Label {
                text: runTimeText
                wrapMode: Text.WordWrap
                maximumLineCount: 1
                width: parent.width - 10
                anchors.horizontalCenter: parent.horizontalCenter
                //verticalAlignment: Text.AlignBottom
                font.pixelSize: 85
                font.capitalization: Font.SmallCaps
            }
            //Spacer - Replace with Horizontal bar
            Rectangle {
                color: "grey"
                height: 1
                width: parent.width - 40
                anchors.horizontalCenter: parent.horizontalCenter
            }

            //Row {}
            Label {
                text: "Distance:"
                wrapMode: Text.WordWrap
                maximumLineCount: 1
                width: parent.width - 20
                anchors.horizontalCenter: parent.horizontalCenter
                verticalAlignment: Text.AlignBottom
                font.pixelSize: 18
                font.capitalization: Font.SmallCaps
            }
            Label {
                text: runDistaceText
                wrapMode: Text.WordWrap
                maximumLineCount: 1
                width: parent.width - 10
                anchors.horizontalCenter: parent.horizontalCenter
                //verticalAlignment: Text.AlignBottom
                font.pixelSize: 85
                font.capitalization: Font.SmallCaps
            }
            //Spacer - Replace with Horizontal bar
            Rectangle {
                color: "grey"
                height: 1
                width: parent.width - 40
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Row {
                height: 110
                width: parent.width - 20
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 0
                Column {
                    spacing: 5
                    width: 115
                    height: 40
                    Label {
                        text: "Samples:"
                        wrapMode: Text.WordWrap
                        maximumLineCount: 1
                        width: 115
                        anchors.horizontalCenter: parent.horizontalCenter
                        verticalAlignment: Text.AlignBottom
                        font.pixelSize: 18
                        font.capitalization: Font.SmallCaps
                    }
                    Label {
                        text: detailedentries
                        wrapMode: Text.WordWrap
                        maximumLineCount: 1
                        width: 115
                        anchors.horizontalCenter: parent.horizontalCenter
                        //verticalAlignment: Text.AlignBottom
                        font.pixelSize: 40
                        font.capitalization: Font.SmallCaps
                    }
                }
                Column {
                    width: 195
                    height: 40
                    spacing: 5
                    Label {
                        text: "Current Speed:"
                        wrapMode: Text.WordWrap
                        maximumLineCount: 1
                        width: 195
                        anchors.horizontalCenter: parent.horizontalCenter
                        verticalAlignment: Text.AlignBottom
                        font.pixelSize: 18
                        font.capitalization: Font.SmallCaps
                    }
                    Label {
                        text: (logPosition.position.speedValid== true) ? (logPosition.position.speed*3.6).toFixed(1) + " Km/h" : "No Reading"
                        wrapMode: Text.WordWrap
                        maximumLineCount: 1
                        width: 195
                        anchors.horizontalCenter: parent.horizontalCenter
                        //verticalAlignment: Text.AlignBottom
                        font.pixelSize: (logPosition.position.speedValid== true) ? 40 : 18
                        font.capitalization: Font.SmallCaps
                    }
                }

                Column {
                    width: 170
                    height: 40
                    spacing: 5
                    Label {
                        text: "Updates Every:"
                        wrapMode: Text.WordWrap
                        maximumLineCount: 1
                        width: 170
                        anchors.horizontalCenter: parent.horizontalCenter
                        verticalAlignment: Text.AlignBottom
                        font.pixelSize: 18
                        font.capitalization: Font.SmallCaps
                    }
                    Label {
                        text: updatetimer + " Sec"
                        wrapMode: Text.WordWrap
                        maximumLineCount: 1
                        width: 170
                        anchors.horizontalCenter: parent.horizontalCenter
                        //verticalAlignment: Text.AlignBottom
                        font.pixelSize: 40
                        font.capitalization: Font.SmallCaps
                    }
                }
            }

        }

        // Stop Logs Button
        Button {
            id: stoplogsButton
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Stop Logging"
            width: parent.width - 80
            height: 60
            onClicked: queryLogDialog.open()
            enabled: true
        }

    }

    ToolBarLayout {
        id: startTools
        ToolIcon {
            platformIconId: "toolbar-back-dimmed"
            anchors.left: parent.left
            enabled: false
        }
        ToolIcon {
            platformIconId: "toolbar-list"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: mapLog.open()
        }
    }

    // Menu Options
    // There are old Logs
    Menu {
        id: mapLog
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: "Map your journey"
                onClicked: appWindow.pageStack.push(Qt.resolvedUrl("LoggingMapPage.qml"))
            }
        }
    }

    QueryDialog {
        id: queryLogDialog
        acceptButtonText: "Stop"
        rejectButtonText: "Cancel"
        titleText: "Stop Logging?"
        message: "Do you want to stop logging?\n"
        onAccepted: {
            loggingtimer.running = false
            runtimer.running = false
            Storage.stoplog(logruntime)
            firstlogrun = false
            nowLogging = false
            bounceback = false
            pageStack.pop()
        }
        onRejected: { queryLogDialog.close() }
     }

}
