import QtQuick 1.1
import com.nokia.meego 1.1
import QtMobility.location 1.2

import "Storage.js" as Storage

Page {
    tools: startTools
    orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
        theme.inverted = true
    }

    PositionSource {
         id: myPosition
         updateInterval: 300
         active: useGPSOK
         onPositionChanged: myPosition.active = false
     }

    onStatusChanged: {
        if (status == PageStatus.Activating) {
            if(useGPSOK == true) {
                myPosition.active = true
                useGPSbox.visible = false
                useGPSboxDark.visible = false
            }
        }
        //if (status == PageStatus.Active) {
        //    myPosition.active = true
        //}
        if (status == PageStatus.Deactivating) {
            myPosition.active = false
            useGPSbox.visible = true
            useGPSboxDark.visible = true
        }
    }

    Column {
        anchors.top: parent.top
        anchors.topMargin: 20
        width: parent.width
        spacing: 10

        Row {
            spacing: 20
            width: parent.width - 20
            anchors.horizontalCenter: parent.horizontalCenter
            height: childrenRect.height
            Image {
                source: "GPSLogMee80.png"
            }
            Column {
                spacing: 5
                width: 300
                Label {
                    text: "GPS LogMee"
                    font.pixelSize: 30
                }
                Label {
                    text: "GPS Logger for N9/N950"
                    font.pixelSize: 18
                }
            }

        }

        Label {
            text: "A simple application that lets you log your journey with options to review older logs on the phone or Nokia Maps Online."
            wrapMode: Text.WordWrap
            maximumLineCount: 3
            width: parent.width - 20
            anchors.horizontalCenter: parent.horizontalCenter
            font.pixelSize: 22
            font.capitalization: Font.SmallCaps
        }

        // Map Holder
        // Map Element does not seem to follow Anchors.HorizontalCenter?
        Label {
            height: 40
            text: "Current Position:"
            wrapMode: Text.WordWrap
            maximumLineCount: 3
            width: parent.width - 20
            anchors.horizontalCenter: parent.horizontalCenter
            verticalAlignment: Text.AlignBottom
            font.pixelSize: 24
        }
        Rectangle {
            radius: 5
            width: parent.width - 20
            height: 260
            smooth: true
            color: "#333333"
            anchors.horizontalCenter: parent.horizontalCenter
            clip: true

            //GPS Not Active Black Map Overlay
            Rectangle {
                visible: true
                id: useGPSboxDark
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.top: parent.top
                anchors.topMargin: 10
                height: 240
                width: parent.width - 20
                color: "black"
                opacity: 0.8
                clip: true
                smooth: true
                z: 15
            }
            //GPS Not Active TEXT
            Rectangle {
                visible: true
                id: useGPSbox
                anchors.centerIn: parent
                radius: 20
                height: 110
                width: parent.width * 0.8
                color: "#2D7707"
                border.color: "darkgreen"
                border.width: 1
                opacity: 1
                clip: true
                smooth: true
                z: 20
                Column {
                    anchors.centerIn: parent
                    width: parent.width - 30
                    spacing: 10
                    Text {
                        id: bootupGPStext
                        font.pixelSize: 26
                        color: "white"
                        smooth:true
                        text: "GPS Not Active"
                        height: paintedHeight
                        width: parent.width
                        horizontalAlignment: Text.AlignHCenter
                    }
                    Text {
                        id: bootupGPSdetailtext
                        font.pixelSize: 20
                        color: "white"
                        smooth:true
                        text: "Just tap here to start."
                        height: paintedHeight
                        width: parent.width
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Text.AlignHCenter
                    }

                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        useGPSbox.visible = false
                        useGPSboxDark.visible = false
                        myPosition.active = true
                        //applicationupdatetimer.start()
                        //applicationstartingtimer.start()
                    }
                }
            }
            //GPS Map Element
            Map {
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.top: parent.top
                anchors.topMargin: 10
                id: mapStartPage
                plugin : Plugin {
                    name : "nokia";
                    PluginParameter {
                        name: "mapping.cache.size";
                        value: 80000000
                       }
                    PluginParameter {
                        name: "app_id";
                        value: "botE2TQLVokFnpBSBJ2D"
                       }
                    PluginParameter {
                        name: "token";
                        value: "MF2mq6-6dqaIOwnljRTprA"
                    }
                }
                connectivityMode : Map.HybridMode
                height: 240
                width: parent.width - 20
                size.width: parent.width - 20
                size.height: 240
                zoomLevel: 16
                center: Coordinate {
                              latitude: (myPosition.position.latitudeValid == true) ? myPosition.position.coordinate.latitude : 0 //endpointLat currentlat //
                              longitude: (myPosition.position.longitudeValid == true) ? myPosition.position.coordinate.longitude : 0 //endpointLon currentlon //
                          }
                mapType: Map.StreetMap
            }
        }

        //Spacer - Replace with Horizontal bar
        Rectangle {
            color: "black"
            height: 10
            width: 1
        }

        // Start New Log Button
        Button {
            id: startlogButton
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Start a new GPS Log"
            width: parent.width - 80
            height: 60
            onClicked: appWindow.pageStack.push(Qt.resolvedUrl("LoggingPage.qml"))
        }

        //Spacer - Replace with Horizontal bar
        Rectangle {
            color: "black"
            height: 15
            width: 1
        }

        // OLD Logs Button
        Button {
            id: oldlogsButton
            anchors.horizontalCenter: parent.horizontalCenter
            text: "View Old Logs"
            width: parent.width - 80
            height: 60
            onClicked: appWindow.pageStack.push(Qt.resolvedUrl("OldLogsPage.qml"))
            enabled: (countlogindexes == 0) ? false : true
        }

    }

    ToolBarLayout {
        id: startTools
        ToolIcon {
            platformIconId: "toolbar-back-dimmed"
            anchors.left: parent.left
            enabled: false
        }
        ToolIcon {
            platformIconId: "toolbar-settings"
            onClicked: appWindow.pageStack.push(Qt.resolvedUrl("SettingsPage.qml"))
        }
        ToolIcon {
            platformIconId: "toolbar-list"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: appWindow.pageStack.push(Qt.resolvedUrl("InfoPage.qml"))
            //onClicked: mainPageMenuOldLogs.open()
        }
    }

    // Menu Options
    // There are old Logs
    Menu {
        id: mainPageMenuOldLogs
        visualParent: pageStack
        MenuLayout {
            //MenuItem {
               // text: "Start a new GPS Log"
                //onClicked: appWindow.pageStack.push(Qt.resolvedUrl("FeedbackPage.qml"))
            //}
            //MenuItem {
                //text: "View Old GPS Logs"
                //onClicked: appWindow.pageStack.push(Qt.resolvedUrl("OldLogsPage.qml"))
            //}
            MenuItem {
                text: "About GPS LogMee"
                onClicked: appWindow.pageStack.push(Qt.resolvedUrl("InfoPage.qml"))
            }
            MenuItem {
                text: "GPS LogMee Settings"
                onClicked: appWindow.pageStack.push(Qt.resolvedUrl("SettingsPage.qml"))
            }
        }
    }

    // Menu Options
    // There are old Logs
    Menu {
        id: mainPageMenuNoLogs
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: "Start a new GPS Log"
                //onClicked: appWindow.pageStack.push(Qt.resolvedUrl("FeedbackPage.qml"))
            }
            MenuItem {
                text: "About GPS Logger"
                //onClicked: appWindow.pageStack.push(Qt.resolvedUrl("AboutPage.qml"))
            }
        }
    }

}
